@@ -29,10 +29,6 @@
 #include <raptor_config.h>
 #endif
 
-#ifdef WIN32
-#include <win32_config.h>
-#endif
-
 #include <stdio.h>
 #include <string.h>
 #include <stdarg.h>
@@ -47,7 +43,7 @@
 #endif
 
 /* Raptor includes */
-#include <raptor.h>
+#include <raptor2.h>
 
 /* Gtk 2.0 */
 #include <gtk/gtk.h>
