@@ -37,10 +37,6 @@
 #include <raptor_config.h>
 #endif
 
-#ifdef WIN32
-#include <win32_raptor_config.h>
-#endif
-
 #ifdef HAVE_STDLIB_H
 #include <stdlib.h>
 #endif
@@ -51,7 +47,7 @@
 #include "raptor_internal.h"
 
 
-#if RAPTOR_DEBUG > 1
+#if defined(RAPTOR_DEBUG) && RAPTOR_DEBUG > 1
 #define RAPTOR_AVLTREE_DEBUG1(msg) RAPTOR_DEBUG1(msg)
 #else
 #define RAPTOR_AVLTREE_DEBUG1(msg)
@@ -148,7 +144,7 @@ raptor_new_avltree(raptor_data_compare_handler compare_handler,
 {
   raptor_avltree* tree;
   
-  tree = (raptor_avltree*)RAPTOR_MALLOC(raptor_avltree, sizeof(*tree));
+  tree = RAPTOR_MALLOC(raptor_avltree*, sizeof(*tree));
   if(!tree)
     return NULL;
 
@@ -255,14 +251,14 @@ raptor_avltree_add(raptor_avltree* tree, void* p_data)
 {
   int rebalancing = FALSE;
   int rv;
-#if RAPTOR_DEBUG > 1
+#if defined(RAPTOR_DEBUG) && RAPTOR_DEBUG > 1
   RAPTOR_AVLTREE_DEBUG1("Checking tree before adding\n");
   raptor_avltree_check(tree);
 #endif
 
   rv = raptor_avltree_sprout(tree, NULL, &tree->root, p_data,
                              &rebalancing);
-#if RAPTOR_DEBUG > 1
+#if defined(RAPTOR_DEBUG) && RAPTOR_DEBUG > 1
   RAPTOR_AVLTREE_DEBUG1("Checking tree after adding\n");
   raptor_avltree_check(tree);
 #endif
@@ -289,7 +285,7 @@ raptor_avltree_remove(raptor_avltree* tree, void* p_data)
   int rebalancing = FALSE;
   void* rdata;
   
-#if RAPTOR_DEBUG > 1
+#if defined(RAPTOR_DEBUG) && RAPTOR_DEBUG > 1
   RAPTOR_AVLTREE_DEBUG1("Checking tree before removing\n");
   raptor_avltree_dump(tree,stderr);
   raptor_avltree_check(tree);
@@ -299,7 +295,7 @@ raptor_avltree_remove(raptor_avltree* tree, void* p_data)
   if(rdata)
     tree->size--;
 
-#if RAPTOR_DEBUG > 1
+#if defined(RAPTOR_DEBUG) && RAPTOR_DEBUG > 1
   RAPTOR_AVLTREE_DEBUG1("Checking tree after removing\n");
   raptor_avltree_dump(tree,stderr);
   raptor_avltree_check(tree);
@@ -482,7 +478,7 @@ raptor_avltree_sprout_left(raptor_avltree* tree, raptor_avltree_node** node_pp,
     case -1:
       /* left branch was already too long. rebalance */
       RAPTOR_AVLTREE_DEBUG1("LESS: case -1: rebalancing\n");
-#if RAPTOR_DEBUG > 1
+#if defined(RAPTOR_DEBUG) && RAPTOR_DEBUG > 1
       RAPTOR_AVLTREE_DEBUG1("Tree before rebalancing\n");
       raptor_avltree_dump(tree, stderr);
 #endif
@@ -531,14 +527,14 @@ raptor_avltree_sprout_left(raptor_avltree* tree, raptor_avltree_node** node_pp,
         *node_pp = p2;
         (*node_pp)->parent = p_parent;
       } /* end else */
-#if RAPTOR_DEBUG > 1
+#if defined(RAPTOR_DEBUG) && RAPTOR_DEBUG > 1
       RAPTOR_AVLTREE_DEBUG1("Tree after rebalancing\n");
       raptor_avltree_dump(tree, stderr);
 #endif
 
       (*node_pp)->balance = 0;
       *rebalancing_p = FALSE;
-#if RAPTOR_DEBUG > 1
+#if defined(RAPTOR_DEBUG) && RAPTOR_DEBUG > 1
       if(1) {
         unsigned int discard = 0;
         raptor_avltree_check_internal(tree, *node_pp, &discard);
@@ -589,7 +585,7 @@ raptor_avltree_sprout_right(raptor_avltree* tree,
       RAPTOR_AVLTREE_DEBUG1("MORE: balance was off, need to rebalance\n");
       p1 = (*node_pp)->right;
       
-#if RAPTOR_DEBUG > 1
+#if defined(RAPTOR_DEBUG) && RAPTOR_DEBUG > 1
       RAPTOR_AVLTREE_DEBUG1("Tree before rebalancing\n");
       raptor_avltree_dump(tree, stderr);
 #endif
@@ -638,13 +634,13 @@ raptor_avltree_sprout_right(raptor_avltree* tree,
         (*node_pp)->parent = p_parent;
       } /* end else */
       
-#if RAPTOR_DEBUG > 1
+#if defined(RAPTOR_DEBUG) && RAPTOR_DEBUG > 1
       RAPTOR_AVLTREE_DEBUG1("Tree after rebalancing\n");
       raptor_avltree_dump(tree, stderr);
 #endif
       (*node_pp)->balance = 0;
       *rebalancing_p = FALSE;
-#if RAPTOR_DEBUG > 1
+#if defined(RAPTOR_DEBUG) && RAPTOR_DEBUG > 1
       if(1) {
         unsigned int discard = 0;
         raptor_avltree_check_internal(tree, *node_pp, &discard);
@@ -670,7 +666,7 @@ raptor_avltree_sprout(raptor_avltree* tree, raptor_avltree_node* parent,
 {
   int cmp;
 
-#if RAPTOR_DEBUG > 1
+#if defined(RAPTOR_DEBUG) && RAPTOR_DEBUG > 1
   RAPTOR_AVLTREE_DEBUG1("Enter\n");
   if ( *node_pp) { 
       raptor_avltree_print_node(*node_pp);
@@ -684,15 +680,14 @@ raptor_avltree_sprout(raptor_avltree* tree, raptor_avltree_node* parent,
   /* If grounded, add the node here, set the rebalance flag and return */
   if(!*node_pp) {
     RAPTOR_AVLTREE_DEBUG1("grounded. adding new node, setting rebalancing flag true\n");
-    *node_pp = (raptor_avltree_node*)RAPTOR_MALLOC(raptor_avltree_node,
-                                                   sizeof(**node_pp));
+    *node_pp = RAPTOR_MALLOC(raptor_avltree_node*, sizeof(**node_pp));
     if(!*node_pp) {
       if(tree->free_handler)
         tree->free_handler(p_data);
       return RAPTOR_AVLTREE_ENOMEM;
     }
 
-#if RAPTOR_DEBUG > 1
+#if defined(RAPTOR_DEBUG) && RAPTOR_DEBUG > 1
     RAPTOR_DEBUG2("Creating new node %p\n", *node_pp);
 #endif
     
@@ -705,7 +700,7 @@ raptor_avltree_sprout(raptor_avltree* tree, raptor_avltree_node* parent,
 
     tree->size++;
 
-#if RAPTOR_DEBUG > 1
+#if defined(RAPTOR_DEBUG) && RAPTOR_DEBUG > 1
     raptor_avltree_check_node(tree, *node_pp, 0, 0);
 
     RAPTOR_AVLTREE_DEBUG1("Tree now looks this way\n");
@@ -716,7 +711,7 @@ raptor_avltree_sprout(raptor_avltree* tree, raptor_avltree_node* parent,
   }
 
   /* check node */
-#if RAPTOR_DEBUG > 1
+#if defined(RAPTOR_DEBUG) && RAPTOR_DEBUG > 1
   raptor_avltree_check_node(tree, *node_pp, 0, 0);
 #endif
   /* compare the data */
@@ -1286,8 +1281,7 @@ raptor_new_avltree_iterator(raptor_avltree* tree, void* range,
 {
   raptor_avltree_iterator* iterator;
 
-  iterator = (raptor_avltree_iterator*)RAPTOR_CALLOC(raptor_avltree_iterator,
-                                                     1, sizeof(*iterator));
+  iterator = RAPTOR_CALLOC(raptor_avltree_iterator*, 1, sizeof(*iterator));
   if(!iterator)
     return NULL;
 
@@ -1572,7 +1566,7 @@ typedef struct
   int failed;
 } visit_state;
   
-#if RAPTOR_DEBUG > 1
+#if defined(RAPTOR_DEBUG) && RAPTOR_DEBUG > 1
 static int
 print_string(int depth, void* data, void *user_data) 
 {
@@ -1642,7 +1636,7 @@ main(int argc, char *argv[])
     int rc;
     void* node;
 
-#if RAPTOR_DEBUG > 1
+#if defined(RAPTOR_DEBUG) && RAPTOR_DEBUG > 1
     fprintf(stderr, "%s: Adding tree item '%s'\n", program, items[i]);
 #endif
   
@@ -1667,7 +1661,7 @@ main(int argc, char *argv[])
     }
   }
 
-#if RAPTOR_DEBUG > 1
+#if defined(RAPTOR_DEBUG) && RAPTOR_DEBUG > 1
   fprintf(stderr, "%s: Printing tree\n", program);
   vs.fh = stderr;
   vs.count = 0;
@@ -1682,7 +1676,7 @@ main(int argc, char *argv[])
   for(i = 0; delete_items[i]; i++) {
     int rc;
 
-#if RAPTOR_DEBUG > 1
+#if defined(RAPTOR_DEBUG) && RAPTOR_DEBUG > 1
     fprintf(stderr, "%s: Deleting tree item '%s'\n", program, delete_items[i]);
 #endif
   
@@ -1700,7 +1694,7 @@ main(int argc, char *argv[])
   }
 
 
-#if RAPTOR_DEBUG > 1
+#if defined(RAPTOR_DEBUG) && RAPTOR_DEBUG > 1
   fprintf(stderr, "%s: Walking tree forwards via iterator\n", program);
 #endif
   iter = raptor_new_avltree_iterator(tree, NULL, NULL, 1);
@@ -1712,7 +1706,7 @@ main(int argc, char *argv[])
               i, result, data);
       exit(1);
     }
-#if RAPTOR_DEBUG > 1
+#if defined(RAPTOR_DEBUG) && RAPTOR_DEBUG > 1
     fprintf(stderr, "%3d: Got '%s'\n", i, data);
 #endif
     if(raptor_avltree_iterator_next(iter))
@@ -1725,7 +1719,7 @@ main(int argc, char *argv[])
   raptor_free_avltree_iterator(iter);
 
 
-#if RAPTOR_DEBUG > 1
+#if defined(RAPTOR_DEBUG) && RAPTOR_DEBUG > 1
   fprintf(stderr, "%s: Checking tree\n", program);
 #endif
   vs.count = 0;
@@ -1754,7 +1748,7 @@ main(int argc, char *argv[])
   }
   
 
-#if RAPTOR_DEBUG > 1
+#if defined(RAPTOR_DEBUG) && RAPTOR_DEBUG > 1
   fprintf(stderr, "%s: Freeing tree\n", program);
 #endif
   raptor_free_avltree(tree);
