@@ -35,10 +35,6 @@
 #include <raptor_config.h>
 #endif
 
-#ifdef WIN32
-#include <win32_raptor_config.h>
-#endif
-
 #include <stdio.h>
 #include <string.h>
 #include <ctype.h>
@@ -208,7 +204,8 @@ raptor_grddl_xsltGenericError_handler(void *user_data, const char *msg, ...)
       nmsg[length-1] = '\0';
   }
 
-  raptor_parser_error_varargs(rdf_parser, nmsg ? nmsg : msg, arguments);
+  raptor_parser_log_error_varargs(rdf_parser, RAPTOR_LOG_LEVEL_ERROR,
+                                  nmsg ? nmsg : msg, arguments);
   if(nmsg)
     RAPTOR_FREE(char*, nmsg);
 
@@ -816,9 +813,10 @@ raptor_grddl_run_grddl_transform_doc(raptor_parser* rdf_parser,
   
   if(grddl_parser->internal_parser) {
     /* generate the triples */
-    raptor_parser_parse_start(grddl_parser->internal_parser, base_uri);
-    raptor_parser_parse_chunk(grddl_parser->internal_parser,
-                              doc_txt, doc_txt_len, 1);
+    ret = raptor_parser_parse_start(grddl_parser->internal_parser, base_uri);
+    if(!ret)
+      ret = raptor_parser_parse_chunk(grddl_parser->internal_parser,
+                                      doc_txt, doc_txt_len, 1);
   }
   
   cleanup_xslt:
@@ -1148,7 +1146,7 @@ raptor_grddl_run_xpath_match(raptor_parser* rdf_parser,
     else
       base_uri = NULL;
     
-    if(flags & MATCH_IS_VALUE_LIST) {
+    if(uri_string && (flags & MATCH_IS_VALUE_LIST)) {
       char *start;
       char *end;
       char* buffer;
@@ -1186,8 +1184,10 @@ raptor_grddl_run_xpath_match(raptor_parser* rdf_parser,
     } else if(flags & MATCH_IS_HARDCODED) {
       RAPTOR_DEBUG2("Got hardcoded XSLT match for %s\n", xpathExpr);
       /* return at first match, that's enough */
+      if(base_uri)
+        raptor_free_uri(base_uri);
       break;
-    } else {
+    } else if(uri_string) {
       grddl_xml_context* xml_context;
       RAPTOR_DEBUG2("Got single match URI '%s'\n", uri_string);
 
@@ -1325,10 +1325,12 @@ raptor_grddl_run_recursive(raptor_parser* rdf_parser, raptor_uri* uri,
       }      
     }
     
-    RAPTOR_FREE(char*, ibuffer);
     raptor_parser_save_content(grddl_parser->internal_parser, 0);
   }
 
+  if(ibuffer)
+    RAPTOR_FREE(char*, ibuffer);
+
   if(rpbc.final_uri)
     raptor_free_uri(rpbc.final_uri);
 
@@ -1449,7 +1451,7 @@ raptor_grddl_parse_chunk(raptor_parser* rdf_parser,
     
       grddl_parser->xml_ctxt->replaceEntities = 1;
       grddl_parser->xml_ctxt->loadsubset = 1;
-    } else if(loop == 1) {
+    } else { /* loop is 1 */
   
       /* try to create an HTML parser context */
       if(RAPTOR_OPTIONS_GET_NUMERIC(rdf_parser, RAPTOR_OPTION_HTML_TAG_SOUP)) {
@@ -1491,10 +1493,9 @@ raptor_grddl_parse_chunk(raptor_parser* rdf_parser,
 
         htmlCtxtUseOptions(grddl_parser->html_ctxt, options);
  
-      } else
+      } else /* No HTML tag soup allowed so continue loop */
         continue;
-    } else
-      continue;
+    }
 
 
     if(grddl_parser->html_ctxt) {
