@@ -26,10 +26,6 @@
 #include <raptor_config.h>
 #endif
 
-#ifdef WIN32
-#include <win32_raptor_config.h>
-#endif
-
 #include <stdio.h>
 #include <string.h>
 #include <ctype.h>
@@ -54,7 +50,7 @@ struct raptor_iostream_s
   
   void *user_data;
   const raptor_iostream_handler* handler;
-  unsigned long offset;
+  size_t offset;
   unsigned int mode;
   int flags;
 };
@@ -1135,7 +1131,7 @@ raptor_new_iostream_from_string(raptor_world *world,
 unsigned long
 raptor_iostream_tell(raptor_iostream *iostr)
 {
-  return iostr->offset;
+  return RAPTOR_BAD_CAST(unsigned long, iostr->offset);
 }
 
 
@@ -1354,12 +1350,12 @@ static int
 test_read_from_filename(raptor_world *world,
                         const char* filename, 
                         const char* test_string, size_t test_string_len,
-                        const unsigned int expected_len,
-                        const unsigned int expected_len2)
+                        const int expected_len,
+                        const int expected_len2)
 {
   raptor_iostream *iostr = NULL;
   char buffer[READ_BUFFER_SIZE];
-  unsigned long count;
+  int count;
   int rc = 0;
   const char* const label="read iostream from filename";
 
