@@ -27,11 +27,6 @@
 #include <raptor_config.h>
 #endif
 
-#ifdef WIN32
-#include <win32_raptor_config.h>
-#endif
-
-
 #include <stdio.h>
 #include <string.h>
 #include <ctype.h>
@@ -424,15 +419,21 @@ raptor_namespaces_find_namespace(raptor_namespace_stack *nstack,
 {
   raptor_namespace* ns;
   unsigned int hash = raptor_hash_ns_string(prefix, prefix_length);
-  const int bucket = hash % (nstack->table_size);
+  int bucket;
 
+  if(!nstack || !nstack->table_size)
+    return NULL;
+
+  bucket = hash % (nstack->table_size);
   for(ns = nstack->table[bucket]; ns ; ns = ns->next) {
-    if(!prefix && !ns->prefix)
-      break;
-    
-    if((unsigned int)prefix_length == ns->prefix_length && 
-       !strncmp((char*)prefix, (char*)ns->prefix, prefix_length))
-      break;
+    if(!prefix) {
+      if(!ns->prefix)
+        break;
+    } else {
+      if((unsigned int)prefix_length == ns->prefix_length && 
+         !strncmp((char*)prefix, (char*)ns->prefix, prefix_length))
+        break;
+    }
   }
 
   return ns;
@@ -767,10 +768,15 @@ raptor_namespace_format_as_xml(const raptor_namespace *ns, size_t *length_p)
   unsigned char *p;
 
   if(ns->uri) {
+    int xlength;
+    
     uri_string = raptor_uri_as_counted_string(ns->uri, &uri_length);
-    xml_uri_length = raptor_xml_escape_string(ns->nstack->world,
-                                              uri_string, uri_length,
-                                              NULL, 0, quote);
+    xlength = raptor_xml_escape_string(ns->nstack->world,
+                                       uri_string, uri_length,
+                                       NULL, 0, quote);
+    if(xlength < 0)
+      return NULL;
+    xml_uri_length = RAPTOR_GOOD_CAST(size_t, xlength);
   }
 
   /* 8 = length of [[xmlns=""] */
@@ -799,10 +805,14 @@ raptor_namespace_format_as_xml(const raptor_namespace *ns, size_t *length_p)
   *p++ = '=';
   *p++ = quote;
   if(uri_length) {
-    raptor_xml_escape_string(ns->nstack->world,
-                             uri_string, uri_length,
-                             p, xml_uri_length, quote);
-    p += xml_uri_length;
+    int xlength;
+
+    xlength = raptor_xml_escape_string(ns->nstack->world,
+                                       uri_string, uri_length,
+                                       p, xml_uri_length, quote);
+    if(xlength < 0)
+      return NULL;
+    p += RAPTOR_GOOD_CAST(size_t, xlength);
   }
   *p++ = quote;
   /* *p used here since we never need to use value of p again [CLANG] */
