@@ -27,11 +27,6 @@
 #include <raptor_config.h>
 #endif
 
-#ifdef WIN32
-#include <win32_raptor_config.h>
-#endif
-
-
 #include <stdio.h>
 #include <string.h>
 #include <ctype.h>
@@ -351,8 +346,9 @@ raptor_new_parser(raptor_world* world, const char *name)
   
   raptor_object_options_init(&rdf_parser->options, RAPTOR_OPTION_AREA_PARSER);
 
-  /* Initialise default (lax) option values */
-  raptor_parser_set_option(rdf_parser, RAPTOR_OPTION_STRICT, NULL, 0);
+  /* set parsing strictness from default value */
+  raptor_parser_set_strict(rdf_parser, 
+                           RAPTOR_OPTIONS_GET_NUMERIC(rdf_parser, RAPTOR_OPTION_STRICT));
 
   if(factory->init(rdf_parser, name)) {
     raptor_free_parser(rdf_parser);
@@ -722,7 +718,9 @@ raptor_parser_parse_uri_with_connection(raptor_parser* rdf_parser,
   char* cert_filename = NULL;
   char* cert_type = NULL;
   char* cert_passphrase = NULL;
-  
+  int ssl_verify_peer;
+  int ssl_verify_host;
+
   if(connection) {
     if(rdf_parser->www)
       raptor_free_www(rdf_parser->www);
@@ -784,6 +782,13 @@ raptor_parser_parse_uri_with_connection(raptor_parser* rdf_parser,
     raptor_www_set_ssl_cert_options(rdf_parser->www, cert_filename,
                                     cert_type, cert_passphrase);
   
+  ssl_verify_peer = RAPTOR_OPTIONS_GET_NUMERIC(rdf_parser,
+                                               RAPTOR_OPTION_WWW_SSL_VERIFY_PEER);
+  ssl_verify_host = RAPTOR_OPTIONS_GET_NUMERIC(rdf_parser,
+                                               RAPTOR_OPTION_WWW_SSL_VERIFY_HOST);
+  raptor_www_set_ssl_verify_options(rdf_parser->www, ssl_verify_peer,
+                                    ssl_verify_host);
+
   ret = raptor_www_fetch(rdf_parser->www, uri);
   
   if(!rpbc.started && !ret)
@@ -816,15 +821,14 @@ raptor_parser_fatal_error(raptor_parser* parser, const char *message, ...)
 {
   va_list arguments;
 
-  parser->failed = 1;
-
   va_start(arguments, message);
-  if(parser)
+  if(parser) {
+    parser->failed = 1;
     raptor_log_error_varargs(parser->world,
                              RAPTOR_LOG_LEVEL_FATAL,
                              &parser->locator,
                              message, arguments);
-  else
+  } else
     raptor_log_error_varargs(NULL,
                              RAPTOR_LOG_LEVEL_FATAL, NULL,
                              message, arguments); 
@@ -842,32 +846,35 @@ raptor_parser_error(raptor_parser* parser, const char *message, ...)
 
   va_start(arguments, message);
 
-  raptor_parser_error_varargs(parser, message, arguments);
+  raptor_parser_log_error_varargs(parser, RAPTOR_LOG_LEVEL_ERROR,
+                                  message, arguments);
   
   va_end(arguments);
 }
 
 
 /**
- * raptor_parser_error_varargs:
- * @parser: parser
+ * raptor_parser_log_error_varargs:
+ * @parser: parser (or NULL)
+ * @level: log level
  * @message: error format message
  * @arguments: varargs for message
  *
  * Error from a parser - Internal.
  */  
 void  
-raptor_parser_error_varargs(raptor_parser* parser, const char *message,  
-                            va_list arguments)
+raptor_parser_log_error_varargs(raptor_parser* parser,
+                                raptor_log_level level,
+                                const char *message, va_list arguments)
 {
   if(parser)
     raptor_log_error_varargs(parser->world,
-                             RAPTOR_LOG_LEVEL_ERROR,
+                             level,
                              &parser->locator,
                              message, arguments);
   else
     raptor_log_error_varargs(NULL,
-                             RAPTOR_LOG_LEVEL_ERROR,
+                             level,
                              NULL,
                              message, arguments);
 }
@@ -1161,7 +1168,10 @@ raptor_parser_parse_abort(raptor_parser *rdf_parser)
 raptor_locator*
 raptor_parser_get_locator(raptor_parser *rdf_parser)
 {
-  return &rdf_parser->locator;
+  if(rdf_parser->factory->get_locator)
+    return rdf_parser->factory->get_locator(rdf_parser);
+  else
+    return &rdf_parser->locator;
 }
 
 
@@ -1193,7 +1203,8 @@ static int
 compare_syntax_score(const void *a, const void *b) {
   return ((struct syntax_score*)b)->score - ((struct syntax_score*)a)->score;
 }
-  
+
+#define RAPTOR_MIN_GUESS_SCORE 2
 
 /**
  * raptor_world_guess_parser_name:
@@ -1209,6 +1220,8 @@ compare_syntax_score(const void *a, const void *b) {
  * Find a parser by scoring recognition of the syntax by a block of
  * characters, the content identifier or a mime type.  The content
  * identifier is typically a filename or URI or some other identifier.
+ *
+ * If the guessing finds only low scores, NULL will be returned.
  * 
  * Return value: a parser name or NULL if no guess could be made
  **/
@@ -1240,8 +1253,10 @@ raptor_world_guess_parser_name(raptor_world* world,
 
       p++;
       suffix = RAPTOR_MALLOC(unsigned char*, strlen((const char*)p) + 1);
-      if(!suffix)
+      if(!suffix) {
+        RAPTOR_FREE(syntax_scores, scores);
         return NULL;
+      }
 
       for(from = p, to = suffix; *from; ) {
         unsigned char c = *from++;
@@ -1278,7 +1293,7 @@ raptor_world_guess_parser_name(raptor_world* world,
       if(type_q)
         score = type_q->q;
     }
-    /* mime type match has high Q - return result */
+    /* mime type match has high Q - return factory as result */
     if(score >= 10)
       break;
     
@@ -1294,7 +1309,7 @@ raptor_world_guess_parser_name(raptor_world* world,
           break;
       }
       if(factory_uri_string)
-        /* got an exact match syntax for URI - return result */
+        /* got an exact match syntax for URI - return factory as result */
         break;
     }
     
@@ -1305,6 +1320,9 @@ raptor_world_guess_parser_name(raptor_world* world,
        * RDF/XML examples
        */
 #define FIRSTN 1024
+#if FIRSTN > RAPTOR_READ_BUFFER_SIZE
+#error "RAPTOR_READ_BUFFER_SIZE is not large enough"
+#endif
       if(buffer && len && len > FIRSTN) {
         c = buffer[FIRSTN];
         ((char*)buffer)[FIRSTN] = '\0';
@@ -1326,9 +1344,10 @@ raptor_world_guess_parser_name(raptor_world* world,
   }
   
   if(!factory) {
-    /* sort the scores and pick a factory */
+    /* sort the scores and pick a factory if score is good enough */
     qsort(scores, i, sizeof(struct syntax_score), compare_syntax_score);
-    if(scores[0].score >= 0)
+
+    if(scores[0].score >= RAPTOR_MIN_GUESS_SCORE)
       factory = scores[0].factory;
   }
 
@@ -1669,9 +1688,16 @@ raptor_parser_parse_iostream(raptor_parser* rdf_parser, raptor_iostream *iostr,
     return rc;
   
   while(!raptor_iostream_read_eof(iostr)) {
-    size_t len = raptor_iostream_read_bytes(rdf_parser->buffer, 1,
-                                            RAPTOR_READ_BUFFER_SIZE, iostr);
-    int is_end = (len < RAPTOR_READ_BUFFER_SIZE);
+    int ilen;
+    size_t len;
+    int is_end;
+
+    ilen = raptor_iostream_read_bytes(rdf_parser->buffer, 1,
+                                      RAPTOR_READ_BUFFER_SIZE, iostr);
+    if(ilen < 0)
+      break;
+    len = RAPTOR_GOOD_CAST(size_t, ilen);
+    is_end = (len < RAPTOR_READ_BUFFER_SIZE);
 
     rc = raptor_parser_parse_chunk(rdf_parser, rdf_parser->buffer, len, is_end);
     if(rc || is_end)
