@@ -382,6 +382,7 @@ raptor_turtle_emit_subject_collection_items(raptor_serializer* serializer,
                           context->rdf_first_uri)) {
       raptor_log_error(serializer->world, RAPTOR_LOG_LEVEL_ERROR, NULL,
                        "Malformed collection - first predicate is not rdf:first");
+      raptor_free_avltree_iterator(iter);
       return 1;
     }
     
@@ -413,8 +414,10 @@ raptor_turtle_emit_subject_collection_items(raptor_serializer* serializer,
     }
 
     /* Return error if emitting something failed above */
-    if(rv)
+    if(rv) {
+      raptor_free_avltree_iterator(iter);
       return rv;
+    }
 
     /* last item */
     rv = raptor_avltree_iterator_next(iter);
@@ -428,6 +431,7 @@ raptor_turtle_emit_subject_collection_items(raptor_serializer* serializer,
     if(!raptor_uri_equals(predicate->term->value.uri, context->rdf_rest_uri)) {
       raptor_log_error(serializer->world, RAPTOR_LOG_LEVEL_ERROR, NULL,
                        "Malformed collection - second predicate is not rdf:rest");
+      raptor_free_avltree_iterator(iter);
       return 1;
     }
     
@@ -437,6 +441,7 @@ raptor_turtle_emit_subject_collection_items(raptor_serializer* serializer,
       if(!subject) {
         raptor_log_error(serializer->world, RAPTOR_LOG_LEVEL_ERROR, NULL,
                          "Malformed collection - could not find subject for rdf:rest");
+        raptor_free_avltree_iterator(iter);
         return 1;
       }
 
@@ -453,6 +458,7 @@ raptor_turtle_emit_subject_collection_items(raptor_serializer* serializer,
          !raptor_uri_equals(object->term->value.uri, context->rdf_nil_uri)) {
         raptor_log_error(serializer->world, RAPTOR_LOG_LEVEL_ERROR, NULL,
                          "Malformed collection - last rdf:rest resource is not rdf:nil");
+        raptor_free_avltree_iterator(iter);
         return 1;
       }
       break;
@@ -616,7 +622,10 @@ raptor_turtle_emit_subject(raptor_serializer *serializer,
     if(!iter)
       return 1;
     pred1 = ((raptor_abbrev_node**)raptor_avltree_iterator_get(iter))[0];
-    raptor_avltree_iterator_next(iter);
+    if(raptor_avltree_iterator_next(iter)) {
+      raptor_free_avltree_iterator(iter);
+      return 1;
+    }
     pred2 = ((raptor_abbrev_node**)raptor_avltree_iterator_get(iter))[0];
     raptor_free_avltree_iterator(iter);
 
