@@ -31,8 +31,9 @@ extern "C" {
 
 
 /* turtle_parser.y */
-int turtle_syntax_error(raptor_parser *rdf_parser, const char *message, ...) RAPTOR_PRINTF_FORMAT(2, 3);
-raptor_uri* turtle_qname_to_uri(raptor_parser *rdf_parser, unsigned char *name, size_t name_len);
+RAPTOR_INTERNAL_API int turtle_syntax_error(raptor_parser *rdf_parser, const char *message, ...) RAPTOR_PRINTF_FORMAT(2, 3);
+RAPTOR_INTERNAL_API raptor_uri* turtle_qname_to_uri(raptor_parser *rdf_parser, unsigned char *name, size_t name_len);
+RAPTOR_INTERNAL_API size_t raptor_turtle_expand_name_escapes(unsigned char *name, size_t len, raptor_simple_message_handler error_handler, void *error_data);
 
 /* turtle_lexer.l */
 extern void turtle_token_free(raptor_world* world, int token, YYSTYPE *lval);
@@ -73,7 +74,7 @@ struct raptor_turtle_parser_s {
   raptor_term* graph_name;
 
   /* Allow TRIG extensions */
-  int trig : 1;
+  int trig;
 };
 
 
